==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/ListNamespaceTopicSharedAccessKeysPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property namespaceName Name of the namespace.
 * @property resourceGroupName The name of the resource group within the user's subscription.
 * @property topicName Name of the topic.
 */
public data class ListNamespaceTopicSharedAccessKeysPlainArgs(
    public val namespaceName: String,
    public val resourceGroupName: String,
    public val topicName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs.builder()
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .topicName(topicName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListNamespaceTopicSharedAccessKeysPlainArgs].
 */
@PulumiTagMarker
public class ListNamespaceTopicSharedAccessKeysPlainArgsBuilder internal constructor() {
    private var namespaceName: String? = null

    private var resourceGroupName: String? = null

    private var topicName: String? = null

    /**
     * @param value Name of the namespace.
     */
    @JvmName("vrpyobecrmmdnvki")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value The name of the resource group within the user's subscription.
     */
    @JvmName("ajnsliubawmukejr")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the topic.
     */
    @JvmName("juvarxmutyyjnxvg")
    public suspend fun topicName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.topicName = mapped
    }

    internal fun build(): ListNamespaceTopicSharedAccessKeysPlainArgs =
        ListNamespaceTopicSharedAccessKeysPlainArgs(
            namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            topicName = topicName ?: throw PulumiNullFieldException("topicName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/ListNamespaceTopicSharedAccessKeysPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property namespaceName Name of the namespace.
 * @property resourceGroupName The name of the resource group within the user's subscription.
 * @property topicName Name of the topic.
 */
public data class ListNamespaceTopicSharedAccessKeysPlainArgs(
    public val namespaceName: String,
    public val resourceGroupName: String,
    public val topicName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.ListNamespaceTopicSharedAccessKeysPlainArgs.builder()
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .topicName(topicName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListNamespaceTopicSharedAccessKeysPlainArgs].
 */
@PulumiTagMarker
public class ListNamespaceTopicSharedAccessKeysPlainArgsBuilder internal constructor() {
    private var namespaceName: String? = null

    private var resourceGroupName: String? = null

    private var topicName: String? = null

    /**
     * @param value Name of the namespace.
     */
    @JvmName("ltpxrytspbqhndhh")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value The name of the resource group within the user's subscription.
     */
    @JvmName("rhgogctgoncjsncj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the topic.
     */
    @JvmName("tqnrfkqpjbifscfm")
    public suspend fun topicName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.topicName = mapped
    }

    internal fun build(): ListNamespaceTopicSharedAccessKeysPlainArgs =
        ListNamespaceTopicSharedAccessKeysPlainArgs(
            namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            topicName = topicName ?: throw PulumiNullFieldException("topicName"),
        )
}
